# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_store_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18secret_store_types.proto\x12\x02v1\x1a\roptions.proto\x1a\ntags.proto\"\x9e\x18\n\x0bSecretStore\x12I\n\x03\x61ws\x18\x03 \x01(\x0b\x32\x0c.v1.AWSStoreB,\xf2\xf8\xb3\x07\x1d\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03\x61ws\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x64\n\x0e\x61ws_cert_x_509\x18\x1e \x01(\x0b\x32\x14.v1.AWSCertX509StoreB4\xf2\xf8\xb3\x07%\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0b\x61wsCertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12o\n\x10\x61\x63tive_directory\x18\x9a\x05 \x01(\x0b\x32\x18.v1.ActiveDirectoryStoreB8\xf2\xf8\xb3\x07)\xca\xf3\xb3\x07$\xc2\xf4\xb3\x07\x1f\n\x0cjson_gateway\x12\x0f\x61\x63tiveDirectory\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12O\n\x05\x61zure\x18\x65 \x01(\x0b\x32\x0e.v1.AzureStoreB.\xf2\xf8\xb3\x07\x1f\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05\x61zure\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12l\n\x0f\x63yberark_conjur\x18\xad\x02 \x01(\x0b\x32\x17.v1.CyberarkConjurStoreB7\xf2\xf8\xb3\x07(\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0e\x63yberarkConjur\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x63\n\x0c\x63yberark_pam\x18\xaf\x02 \x01(\x0b\x32\x14.v1.CyberarkPAMStoreB4\xf2\xf8\xb3\x07%\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0b\x63yberarkPAM\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x88\x01\n\x19\x63yberark_pam_experimental\x18\xae\x02 \x01(\x0b\x32 .v1.CyberarkPAMExperimentalStoreB@\xf2\xf8\xb3\x07\x31\xca\xf3\xb3\x07,\xc2\xf4\xb3\x07\'\n\x0cjson_gateway\x12\x17\x63yberarkPAMExperimental\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12V\n\x07\x64\x65linea\x18\xd4\x16 \x01(\x0b\x32\x10.v1.DelineaStoreB0\xf2\xf8\xb3\x07!\xca\xf3\xb3\x07\x1c\xc2\xf4\xb3\x07\x17\n\x0cjson_gateway\x12\x07\x64\x65linea\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12J\n\x03gcp\x18\xc9\x01 \x01(\x0b\x32\x0c.v1.GCPStoreB,\xf2\xf8\xb3\x07\x1d\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03gcp\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x65\n\x0egcp_cert_x_509\x18\xca\x01 \x01(\x0b\x32\x14.v1.GCPCertX509StoreB4\xf2\xf8\xb3\x07%\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bgcpCertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x66\n\rkeyfactor_ssh\x18\xd2\x01 \x01(\x0b\x32\x15.v1.KeyfactorSSHStoreB5\xf2\xf8\xb3\x07&\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0ckeyfactorSSH\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12j\n\x0fkeyfactor_x_509\x18\xc8\x01 \x01(\x0b\x32\x16.v1.KeyfactorX509StoreB6\xf2\xf8\xb3\x07\'\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rkeyfactorX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x63\n\x0cstrong_vault\x18\x90\x03 \x01(\x0b\x32\x14.v1.StrongVaultStoreB4\xf2\xf8\xb3\x07%\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bstrongVault\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x63\n\rvault_awsec_2\x18\x61 \x01(\x0b\x32\x14.v1.VaultAWSEC2StoreB4\xf2\xf8\xb3\x07%\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bvaultAWSEC2\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12z\n\x16vault_awsec_2_cert_ssh\x18\x62 \x01(\x0b\x32\x1b.v1.VaultAWSEC2CertSSHStoreB;\xf2\xf8\xb3\x07,\xca\xf3\xb3\x07\'\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12vaultAWSEC2CertSSH\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12~\n\x18vault_awsec_2_cert_x_509\x18\x64 \x01(\x0b\x32\x1c.v1.VaultAWSEC2CertX509StoreB<\xf2\xf8\xb3\x07-\xca\xf3\xb3\x07(\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13vaultAWSEC2CertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x62\n\x0cvault_awsiam\x18` \x01(\x0b\x32\x14.v1.VaultAWSIAMStoreB4\xf2\xf8\xb3\x07%\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bvaultAWSIAM\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12y\n\x15vault_awsiam_cert_ssh\x18\x63 \x01(\x0b\x32\x1b.v1.VaultAWSIAMCertSSHStoreB;\xf2\xf8\xb3\x07,\xca\xf3\xb3\x07\'\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12vaultAWSIAMCertSSH\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12}\n\x17vault_awsiam_cert_x_509\x18\x66 \x01(\x0b\x32\x1c.v1.VaultAWSIAMCertX509StoreB<\xf2\xf8\xb3\x07-\xca\xf3\xb3\x07(\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13vaultAWSIAMCertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x66\n\x0evault_app_role\x18\x04 \x01(\x0b\x32\x15.v1.VaultAppRoleStoreB5\xf2\xf8\xb3\x07&\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0cvaultAppRole\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12}\n\x17vault_app_role_cert_ssh\x18^ \x01(\x0b\x32\x1c.v1.VaultAppRoleCertSSHStoreB<\xf2\xf8\xb3\x07-\xca\xf3\xb3\x07(\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13vaultAppRoleCertSSH\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x81\x01\n\x19vault_app_role_cert_x_509\x18_ \x01(\x0b\x32\x1d.v1.VaultAppRoleCertX509StoreB=\xf2\xf8\xb3\x07.\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14vaultAppRoleCertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12Y\n\tvault_tls\x18\x01 \x01(\x0b\x32\x11.v1.VaultTLSStoreB1\xf2\xf8\xb3\x07\"\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08vaultTLS\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12p\n\x12vault_tls_cert_ssh\x18\\ \x01(\x0b\x32\x18.v1.VaultTLSCertSSHStoreB8\xf2\xf8\xb3\x07)\xca\xf3\xb3\x07$\xc2\xf4\xb3\x07\x1f\n\x0cjson_gateway\x12\x0fvaultTLSCertSSH\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12t\n\x14vault_tls_cert_x_509\x18] \x01(\x0b\x32\x19.v1.VaultTLSCertX509StoreB9\xf2\xf8\xb3\x07*\xca\xf3\xb3\x07%\xc2\xf4\xb3\x07 \n\x0cjson_gateway\x12\x10vaultTLSCertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12_\n\x0bvault_token\x18\x02 \x01(\x0b\x32\x13.v1.VaultTokenStoreB3\xf2\xf8\xb3\x07$\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\nvaultToken\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12v\n\x14vault_token_cert_ssh\x18Z \x01(\x0b\x32\x1a.v1.VaultTokenCertSSHStoreB:\xf2\xf8\xb3\x07+\xca\xf3\xb3\x07&\xc2\xf4\xb3\x07!\n\x0cjson_gateway\x12\x11vaultTokenCertSSH\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12z\n\x16vault_token_cert_x_509\x18[ \x01(\x0b\x32\x1b.v1.VaultTokenCertX509StoreB;\xf2\xf8\xb3\x07,\xca\xf3\xb3\x07\'\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12vaultTokenCertX509\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42,\n\x0csecret_store\x12\x1c\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04tags\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\"\x89\x03\n\x08\x41WSStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12?\n\x06region\x18\x03 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06region\x12=\n\x08role_arn\x18\x05 \x01(\tB+\xf2\xf8\xb3\x07&\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1c\xc2\xf4\xb3\x07\x17\n\x0cjson_gateway\x12\x07roleArn\x12L\n\x10role_external_id\x18\x06 \x01(\tB2\xf2\xf8\xb3\x07-\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0eroleExternalId\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:T\xfa\xf8\xb3\x07O\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x45\xc2\xf4\xb3\x07\n\n\x03\x63li\x12\x03\x61ws\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03\x61ws\xc2\xf4\xb3\x07\x19\n\x12terraform-provider\x12\x03\x61ws\"\xe6\x04\n\x10\x41WSCertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12=\n\x05\x63\x61\x41rn\x18\x05 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05\x63\x61\x41rn\x12_\n\x16\x63\x65rtificateTemplateArn\x18\x07 \x01(\tB?\xf2\xf8\xb3\x07:\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07+\xc2\xf4\xb3\x07&\n\x0cjson_gateway\x12\x16\x63\x65rtificateTemplateArn\x12[\n\x14issuedCertTTLMinutes\x18\x08 \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12?\n\x06region\x18\x03 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06region\x12I\n\x0bsigningAlgo\x18\x06 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningAlgo\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:n\xfa\xf8\xb3\x07i\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07_\xc2\xf4\xb3\x07\x12\n\x03\x63li\x12\x0b\x61wsCertX509\xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0b\x61wsCertX509\xc2\xf4\xb3\x07#\n\x12terraform-provider\x12\raws_cert_x509\"\x93\x02\n\x14\x41\x63tiveDirectoryStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:N\xfa\xf8\xb3\x07I\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07?\xc2\xf4\xb3\x07\x16\n\x03\x63li\x12\x0f\x61\x63tiveDirectory\xc2\xf4\xb3\x07\x1f\n\x0cjson_gateway\x12\x0f\x61\x63tiveDirectory\"\xeb\x01\n\nAzureStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x44\n\tvault_uri\x18\x03 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08vaultUri\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01::\xfa\xf8\xb3\x07\x35\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07+\xc2\xf4\xb3\x07\x0c\n\x03\x63li\x12\x05\x61zure\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05\x61zure\"\xab\x02\n\x13\x43yberarkConjurStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12?\n\x06\x61ppURL\x18\x03 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06\x61ppUrl\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:v\xfa\xf8\xb3\x07q\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07g\xc2\xf4\xb3\x07\x15\n\x03\x63li\x12\x0e\x63yberarkConjur\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0e\x63yberarkConjur\xc2\xf4\xb3\x07%\n\x12terraform-provider\x12\x0f\x63yberark_conjur\"\x9f\x02\n\x10\x43yberarkPAMStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12?\n\x06\x61ppURL\x18\x03 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06\x61ppUrl\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:m\xfa\xf8\xb3\x07h\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07^\xc2\xf4\xb3\x07\x12\n\x03\x63li\x12\x0b\x63yberarkPAM\xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0b\x63yberarkPAM\xc2\xf4\xb3\x07\"\n\x12terraform-provider\x12\x0c\x63yberark_pam\"\xd8\x02\n\x1c\x43yberarkPAMExperimentalStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12?\n\x06\x61ppURL\x18\x03 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06\x61ppUrl\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x99\x01\xfa\xf8\xb3\x07\x93\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x88\x01\x88\xf4\xb3\x07\x01\xc2\xf4\xb3\x07\x1e\n\x03\x63li\x12\x17\x63yberarkPAMExperimental\xc2\xf4\xb3\x07\'\n\x0cjson_gateway\x12\x17\x63yberarkPAMExperimental\xc2\xf4\xb3\x07/\n\x12terraform-provider\x12\x19\x63yberark_pam_experimental\"\xb3\x02\n\x0c\x44\x65lineaStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x41\n\nserver_url\x18\x03 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tserverUrl\x12\x43\n\x0btenant_name\x18\x04 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\ntenantName\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:>\xfa\xf8\xb3\x07\x39\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07/\xc2\xf4\xb3\x07\x0e\n\x03\x63li\x12\x07\x64\x65linea\xc2\xf4\xb3\x07\x17\n\x0cjson_gateway\x12\x07\x64\x65linea\"\xe6\x01\n\x08GCPStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x45\n\tprojectID\x18\x03 \x01(\tB2\xf2\xf8\xb3\x07-\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tprojectId\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:6\xfa\xf8\xb3\x07\x31\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\'\xc2\xf4\xb3\x07\n\n\x03\x63li\x12\x03gcp\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03gcp\"\x9d\x04\n\x10GCPCertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x36\n\x04\x63\x61ID\x18\x06 \x01(\tB(\xf2\xf8\xb3\x07#\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04\x63\x61Id\x12\x43\n\x08\x63\x61PoolID\x18\x05 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x63\x61PoolId\x12[\n\x14issuedCertTTLMinutes\x18\x07 \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12\x43\n\x08location\x18\x04 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08location\x12\x45\n\tprojectID\x18\x03 \x01(\tB2\xf2\xf8\xb3\x07-\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tprojectId\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:F\xfa\xf8\xb3\x07\x41\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x37\xc2\xf4\xb3\x07\x12\n\x03\x63li\x12\x0bgcpCertX509\xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bgcpCertX509\"\x8a\x08\n\x11KeyfactorSSHStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x44\n\x0c\x63\x61_file_path\x18\x06 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\ncaFilePath\x12[\n\x15\x63\x65rtificate_file_path\x18\x04 \x01(\tB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07(\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13\x63\x65rtificateFilePath\x12t\n\"default_certificate_authority_name\x18\n \x01(\tBH\xf2\xf8\xb3\x07\x43\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x34\xc2\xf4\xb3\x07/\n\x0cjson_gateway\x12\x1f\x64\x65\x66\x61ultCertificateAuthorityName\x12p\n default_certificate_profile_name\x18\x08 \x01(\tBF\xf2\xf8\xb3\x07\x41\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x32\xc2\xf4\xb3\x07-\n\x0cjson_gateway\x12\x1d\x64\x65\x66\x61ultCertificateProfileName\x12m\n\x1f\x64\x65\x66\x61ult_end_entity_profile_name\x18\t \x01(\tBD\xf2\xf8\xb3\x07?\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x30\xc2\xf4\xb3\x07+\n\x0cjson_gateway\x12\x1b\x64\x65\x66\x61ultEndEntityProfileName\x12Y\n\x17\x65nrollment_code_env_var\x18\x0c \x01(\tB8\xf2\xf8\xb3\x07\x33\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14\x65nrollmentCodeEnvVar\x12\x61\n\x1b\x65nrollment_username_env_var\x18\x0b \x01(\tB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x0cjson_gateway\x12\x18\x65nrollmentUsernameEnvVar\x12\x46\n\rkey_file_path\x18\x05 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bkeyFilePath\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:H\xfa\xf8\xb3\x07\x43\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x39\xc2\xf4\xb3\x07\x13\n\x03\x63li\x12\x0ckeyfactorSSH\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0ckeyfactorSSH\"\x8d\x08\n\x12KeyfactorX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x44\n\x0c\x63\x61_file_path\x18\x06 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\ncaFilePath\x12[\n\x15\x63\x65rtificate_file_path\x18\x04 \x01(\tB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07(\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13\x63\x65rtificateFilePath\x12t\n\"default_certificate_authority_name\x18\n \x01(\tBH\xf2\xf8\xb3\x07\x43\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x34\xc2\xf4\xb3\x07/\n\x0cjson_gateway\x12\x1f\x64\x65\x66\x61ultCertificateAuthorityName\x12p\n default_certificate_profile_name\x18\x08 \x01(\tBF\xf2\xf8\xb3\x07\x41\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x32\xc2\xf4\xb3\x07-\n\x0cjson_gateway\x12\x1d\x64\x65\x66\x61ultCertificateProfileName\x12m\n\x1f\x64\x65\x66\x61ult_end_entity_profile_name\x18\t \x01(\tBD\xf2\xf8\xb3\x07?\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x30\xc2\xf4\xb3\x07+\n\x0cjson_gateway\x12\x1b\x64\x65\x66\x61ultEndEntityProfileName\x12Y\n\x17\x65nrollment_code_env_var\x18\x0c \x01(\tB8\xf2\xf8\xb3\x07\x33\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14\x65nrollmentCodeEnvVar\x12\x61\n\x1b\x65nrollment_username_env_var\x18\x0b \x01(\tB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x0cjson_gateway\x12\x18\x65nrollmentUsernameEnvVar\x12\x46\n\rkey_file_path\x18\x05 \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bkeyFilePath\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12$\n\x04tags\x18\x83\x80\x02 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:J\xfa\xf8\xb3\x07\x45\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07;\xc2\xf4\xb3\x07\x14\n\x03\x63li\x12\rkeyfactorX509\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rkeyfactorX509\"\xdc\x01\n\x10StrongVaultStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x03 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:m\xfa\xf8\xb3\x07h\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07^\xc2\xf4\xb3\x07\x12\n\x03\x63li\x12\x0bstrongVault\xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bstrongVault\xc2\xf4\xb3\x07\"\n\x12terraform-provider\x12\x0cstrong_vault\"\xef\x02\n\x10VaultAWSEC2Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12\"\n\x04tags\x18\x08 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:n\xfa\xf8\xb3\x07i\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07_\xc2\xf4\xb3\x07\x12\n\x03\x63li\x12\x0bvaultAWSEC2\xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bvaultAWSEC2\xc2\xf4\xb3\x07#\n\x12terraform-provider\x12\rvault_aws_ec2\"\x89\x05\n\x17VaultAWSEC2CertSSHStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12O\n\x0fssh_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rsshMountPoint\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x86\x01\xfa\xf8\xb3\x07\x80\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07v\xc2\xf4\xb3\x07\x19\n\x03\x63li\x12\x12vaultAWSEC2CertSSH\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12vaultAWSEC2CertSSH\xc2\xf4\xb3\x07,\n\x12terraform-provider\x12\x16vault_aws_ec2_cert_ssh\"\x8d\x05\n\x18VaultAWSEC2CertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12O\n\x0fpki_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rpkiMountPoint\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x89\x01\xfa\xf8\xb3\x07\x83\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07y\xc2\xf4\xb3\x07\x1a\n\x03\x63li\x12\x13vaultAWSEC2CertX509\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13vaultAWSEC2CertX509\xc2\xf4\xb3\x07-\n\x12terraform-provider\x12\x17vault_aws_ec2_cert_x509\"\xef\x02\n\x10VaultAWSIAMStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12\"\n\x04tags\x18\x08 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:n\xfa\xf8\xb3\x07i\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07_\xc2\xf4\xb3\x07\x12\n\x03\x63li\x12\x0bvaultAWSIAM\xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bvaultAWSIAM\xc2\xf4\xb3\x07#\n\x12terraform-provider\x12\rvault_aws_iam\"\x89\x05\n\x17VaultAWSIAMCertSSHStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12O\n\x0fssh_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rsshMountPoint\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x86\x01\xfa\xf8\xb3\x07\x80\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07v\xc2\xf4\xb3\x07\x19\n\x03\x63li\x12\x12vaultAWSIAMCertSSH\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12vaultAWSIAMCertSSH\xc2\xf4\xb3\x07,\n\x12terraform-provider\x12\x16vault_aws_iam_cert_ssh\"\x8d\x05\n\x18VaultAWSIAMCertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12O\n\x0fpki_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rpkiMountPoint\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x89\x01\xfa\xf8\xb3\x07\x83\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07y\xc2\xf4\xb3\x07\x1a\n\x03\x63li\x12\x13vaultAWSIAMCertX509\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13vaultAWSIAMCertX509\xc2\xf4\xb3\x07-\n\x12terraform-provider\x12\x17vault_aws_iam_cert_x509\"\xf2\x02\n\x11VaultAppRoleStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12\"\n\x04tags\x18\x08 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:p\xfa\xf8\xb3\x07k\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x61\xc2\xf4\xb3\x07\x13\n\x03\x63li\x12\x0cvaultAppRole\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0cvaultAppRole\xc2\xf4\xb3\x07#\n\x12terraform-provider\x12\rvault_approle\"\x8c\x05\n\x18VaultAppRoleCertSSHStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12O\n\x0fssh_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rsshMountPoint\x12\"\n\x04tags\x18\x08 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x88\x01\xfa\xf8\xb3\x07\x82\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07x\xc2\xf4\xb3\x07\x1a\n\x03\x63li\x12\x13vaultAppRoleCertSSH\xc2\xf4\xb3\x07#\n\x0cjson_gateway\x12\x13vaultAppRoleCertSSH\xc2\xf4\xb3\x07,\n\x12terraform-provider\x12\x16vault_approle_cert_ssh\"\x90\x05\n\x19VaultAppRoleCertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12O\n\x0fpki_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rpkiMountPoint\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12\"\n\x04tags\x18\x08 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x8b\x01\xfa\xf8\xb3\x07\x85\x01\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07{\xc2\xf4\xb3\x07\x1b\n\x03\x63li\x12\x14vaultAppRoleCertX509\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14vaultAppRoleCertX509\xc2\xf4\xb3\x07-\n\x12terraform-provider\x12\x17vault_approle_cert_x509\"\xcc\x04\n\rVaultTLSStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x44\n\x0c\x43\x41_cert_path\x18\x04 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\ncaCertPath\x12Q\n\x10\x63lient_cert_path\x18\x05 \x01(\tB7\xf2\xf8\xb3\x07\x32\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0e\x63lientCertPath\x12O\n\x0f\x63lient_key_path\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rclientKeyPath\x12@\n\tnamespace\x18\x08 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:d\xfa\xf8\xb3\x07_\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07U\xc2\xf4\xb3\x07\x0f\n\x03\x63li\x12\x08vaultTLS\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08vaultTLS\xc2\xf4\xb3\x07\x1f\n\x12terraform-provider\x12\tvault_tls\"\xe4\x06\n\x14VaultTLSCertSSHStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x44\n\x0c\x43\x41_cert_path\x18\x04 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\ncaCertPath\x12Q\n\x10\x63lient_cert_path\x18\x05 \x01(\tB7\xf2\xf8\xb3\x07\x32\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0e\x63lientCertPath\x12O\n\x0f\x63lient_key_path\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rclientKeyPath\x12[\n\x14issuedCertTTLMinutes\x18\x0b \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x08 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\n \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12O\n\x0fssh_mount_point\x18\t \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rsshMountPoint\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:{\xfa\xf8\xb3\x07v\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07l\xc2\xf4\xb3\x07\x16\n\x03\x63li\x12\x0fvaultTLSCertSSH\xc2\xf4\xb3\x07\x1f\n\x0cjson_gateway\x12\x0fvaultTLSCertSSH\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12vault_tls_cert_ssh\"\xe8\x06\n\x15VaultTLSCertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x44\n\x0c\x43\x41_cert_path\x18\x04 \x01(\tB.\xf2\xf8\xb3\x07)\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1f\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\ncaCertPath\x12Q\n\x10\x63lient_cert_path\x18\x05 \x01(\tB7\xf2\xf8\xb3\x07\x32\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0e\x63lientCertPath\x12O\n\x0f\x63lient_key_path\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rclientKeyPath\x12[\n\x14issuedCertTTLMinutes\x18\x0b \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x08 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12O\n\x0fpki_mount_point\x18\t \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rpkiMountPoint\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\n \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:~\xfa\xf8\xb3\x07y\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07o\xc2\xf4\xb3\x07\x17\n\x03\x63li\x12\x10vaultTLSCertX509\xc2\xf4\xb3\x07 \n\x0cjson_gateway\x12\x10vaultTLSCertX509\xc2\xf4\xb3\x07)\n\x12terraform-provider\x12\x13vault_tls_cert_x509\"\xea\x02\n\x0fVaultTokenStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:j\xfa\xf8\xb3\x07\x65\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07[\xc2\xf4\xb3\x07\x11\n\x03\x63li\x12\nvaultToken\xc2\xf4\xb3\x07\x1a\n\x0cjson_gateway\x12\nvaultToken\xc2\xf4\xb3\x07!\n\x12terraform-provider\x12\x0bvault_token\"\x83\x05\n\x16VaultTokenCertSSHStore\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\t \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12O\n\x0fssh_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rsshMountPoint\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x81\x01\xfa\xf8\xb3\x07|\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07r\xc2\xf4\xb3\x07\x18\n\x03\x63li\x12\x11vaultTokenCertSSH\xc2\xf4\xb3\x07!\n\x0cjson_gateway\x12\x11vaultTokenCertSSH\xc2\xf4\xb3\x07*\n\x12terraform-provider\x12\x14vault_token_cert_ssh\"\x87\x05\n\x17VaultTokenCertX509Store\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12[\n\x14issuedCertTTLMinutes\x18\x08 \x01(\x05\x42=\xf2\xf8\xb3\x07\x38\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07)\xc2\xf4\xb3\x07$\n\x0cjson_gateway\x12\x14issuedCertTtlMinutes\x12@\n\tnamespace\x18\x05 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tnamespace\x12O\n\x0fpki_mount_point\x18\x06 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rpkiMountPoint\x12N\n\x0eserver_address\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rserverAddress\x12J\n\x0csigning_role\x18\x07 \x01(\tB4\xf2\xf8\xb3\x07/\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0bsigningRole\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x84\x01\xfa\xf8\xb3\x07\x7f\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07u\xc2\xf4\xb3\x07\x19\n\x03\x63li\x12\x12vaultTokenCertX509\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12vaultTokenCertX509\xc2\xf4\xb3\x07+\n\x12terraform-provider\x12\x15vault_token_cert_x509Bm\n\x19\x63om.strongdm.api.plumbingB\x19SecretStoresTypesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_SECRETSTORE = DESCRIPTOR.message_types_by_name['SecretStore']
_AWSSTORE = DESCRIPTOR.message_types_by_name['AWSStore']
_AWSCERTX509STORE = DESCRIPTOR.message_types_by_name['AWSCertX509Store']
_ACTIVEDIRECTORYSTORE = DESCRIPTOR.message_types_by_name['ActiveDirectoryStore']
_AZURESTORE = DESCRIPTOR.message_types_by_name['AzureStore']
_CYBERARKCONJURSTORE = DESCRIPTOR.message_types_by_name['CyberarkConjurStore']
_CYBERARKPAMSTORE = DESCRIPTOR.message_types_by_name['CyberarkPAMStore']
_CYBERARKPAMEXPERIMENTALSTORE = DESCRIPTOR.message_types_by_name['CyberarkPAMExperimentalStore']
_DELINEASTORE = DESCRIPTOR.message_types_by_name['DelineaStore']
_GCPSTORE = DESCRIPTOR.message_types_by_name['GCPStore']
_GCPCERTX509STORE = DESCRIPTOR.message_types_by_name['GCPCertX509Store']
_KEYFACTORSSHSTORE = DESCRIPTOR.message_types_by_name['KeyfactorSSHStore']
_KEYFACTORX509STORE = DESCRIPTOR.message_types_by_name['KeyfactorX509Store']
_STRONGVAULTSTORE = DESCRIPTOR.message_types_by_name['StrongVaultStore']
_VAULTAWSEC2STORE = DESCRIPTOR.message_types_by_name['VaultAWSEC2Store']
_VAULTAWSEC2CERTSSHSTORE = DESCRIPTOR.message_types_by_name['VaultAWSEC2CertSSHStore']
_VAULTAWSEC2CERTX509STORE = DESCRIPTOR.message_types_by_name['VaultAWSEC2CertX509Store']
_VAULTAWSIAMSTORE = DESCRIPTOR.message_types_by_name['VaultAWSIAMStore']
_VAULTAWSIAMCERTSSHSTORE = DESCRIPTOR.message_types_by_name['VaultAWSIAMCertSSHStore']
_VAULTAWSIAMCERTX509STORE = DESCRIPTOR.message_types_by_name['VaultAWSIAMCertX509Store']
_VAULTAPPROLESTORE = DESCRIPTOR.message_types_by_name['VaultAppRoleStore']
_VAULTAPPROLECERTSSHSTORE = DESCRIPTOR.message_types_by_name['VaultAppRoleCertSSHStore']
_VAULTAPPROLECERTX509STORE = DESCRIPTOR.message_types_by_name['VaultAppRoleCertX509Store']
_VAULTTLSSTORE = DESCRIPTOR.message_types_by_name['VaultTLSStore']
_VAULTTLSCERTSSHSTORE = DESCRIPTOR.message_types_by_name['VaultTLSCertSSHStore']
_VAULTTLSCERTX509STORE = DESCRIPTOR.message_types_by_name['VaultTLSCertX509Store']
_VAULTTOKENSTORE = DESCRIPTOR.message_types_by_name['VaultTokenStore']
_VAULTTOKENCERTSSHSTORE = DESCRIPTOR.message_types_by_name['VaultTokenCertSSHStore']
_VAULTTOKENCERTX509STORE = DESCRIPTOR.message_types_by_name['VaultTokenCertX509Store']
SecretStore = _reflection.GeneratedProtocolMessageType('SecretStore', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStore)
  })
_sym_db.RegisterMessage(SecretStore)

AWSStore = _reflection.GeneratedProtocolMessageType('AWSStore', (_message.Message,), {
  'DESCRIPTOR' : _AWSSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.AWSStore)
  })
_sym_db.RegisterMessage(AWSStore)

AWSCertX509Store = _reflection.GeneratedProtocolMessageType('AWSCertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _AWSCERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.AWSCertX509Store)
  })
_sym_db.RegisterMessage(AWSCertX509Store)

ActiveDirectoryStore = _reflection.GeneratedProtocolMessageType('ActiveDirectoryStore', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEDIRECTORYSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActiveDirectoryStore)
  })
_sym_db.RegisterMessage(ActiveDirectoryStore)

AzureStore = _reflection.GeneratedProtocolMessageType('AzureStore', (_message.Message,), {
  'DESCRIPTOR' : _AZURESTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.AzureStore)
  })
_sym_db.RegisterMessage(AzureStore)

CyberarkConjurStore = _reflection.GeneratedProtocolMessageType('CyberarkConjurStore', (_message.Message,), {
  'DESCRIPTOR' : _CYBERARKCONJURSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.CyberarkConjurStore)
  })
_sym_db.RegisterMessage(CyberarkConjurStore)

CyberarkPAMStore = _reflection.GeneratedProtocolMessageType('CyberarkPAMStore', (_message.Message,), {
  'DESCRIPTOR' : _CYBERARKPAMSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.CyberarkPAMStore)
  })
_sym_db.RegisterMessage(CyberarkPAMStore)

CyberarkPAMExperimentalStore = _reflection.GeneratedProtocolMessageType('CyberarkPAMExperimentalStore', (_message.Message,), {
  'DESCRIPTOR' : _CYBERARKPAMEXPERIMENTALSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.CyberarkPAMExperimentalStore)
  })
_sym_db.RegisterMessage(CyberarkPAMExperimentalStore)

DelineaStore = _reflection.GeneratedProtocolMessageType('DelineaStore', (_message.Message,), {
  'DESCRIPTOR' : _DELINEASTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.DelineaStore)
  })
_sym_db.RegisterMessage(DelineaStore)

GCPStore = _reflection.GeneratedProtocolMessageType('GCPStore', (_message.Message,), {
  'DESCRIPTOR' : _GCPSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.GCPStore)
  })
_sym_db.RegisterMessage(GCPStore)

GCPCertX509Store = _reflection.GeneratedProtocolMessageType('GCPCertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _GCPCERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.GCPCertX509Store)
  })
_sym_db.RegisterMessage(GCPCertX509Store)

KeyfactorSSHStore = _reflection.GeneratedProtocolMessageType('KeyfactorSSHStore', (_message.Message,), {
  'DESCRIPTOR' : _KEYFACTORSSHSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.KeyfactorSSHStore)
  })
_sym_db.RegisterMessage(KeyfactorSSHStore)

KeyfactorX509Store = _reflection.GeneratedProtocolMessageType('KeyfactorX509Store', (_message.Message,), {
  'DESCRIPTOR' : _KEYFACTORX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.KeyfactorX509Store)
  })
_sym_db.RegisterMessage(KeyfactorX509Store)

StrongVaultStore = _reflection.GeneratedProtocolMessageType('StrongVaultStore', (_message.Message,), {
  'DESCRIPTOR' : _STRONGVAULTSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.StrongVaultStore)
  })
_sym_db.RegisterMessage(StrongVaultStore)

VaultAWSEC2Store = _reflection.GeneratedProtocolMessageType('VaultAWSEC2Store', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAWSEC2STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAWSEC2Store)
  })
_sym_db.RegisterMessage(VaultAWSEC2Store)

VaultAWSEC2CertSSHStore = _reflection.GeneratedProtocolMessageType('VaultAWSEC2CertSSHStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAWSEC2CERTSSHSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAWSEC2CertSSHStore)
  })
_sym_db.RegisterMessage(VaultAWSEC2CertSSHStore)

VaultAWSEC2CertX509Store = _reflection.GeneratedProtocolMessageType('VaultAWSEC2CertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAWSEC2CERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAWSEC2CertX509Store)
  })
_sym_db.RegisterMessage(VaultAWSEC2CertX509Store)

VaultAWSIAMStore = _reflection.GeneratedProtocolMessageType('VaultAWSIAMStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAWSIAMSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAWSIAMStore)
  })
_sym_db.RegisterMessage(VaultAWSIAMStore)

VaultAWSIAMCertSSHStore = _reflection.GeneratedProtocolMessageType('VaultAWSIAMCertSSHStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAWSIAMCERTSSHSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAWSIAMCertSSHStore)
  })
_sym_db.RegisterMessage(VaultAWSIAMCertSSHStore)

VaultAWSIAMCertX509Store = _reflection.GeneratedProtocolMessageType('VaultAWSIAMCertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAWSIAMCERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAWSIAMCertX509Store)
  })
_sym_db.RegisterMessage(VaultAWSIAMCertX509Store)

VaultAppRoleStore = _reflection.GeneratedProtocolMessageType('VaultAppRoleStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAPPROLESTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAppRoleStore)
  })
_sym_db.RegisterMessage(VaultAppRoleStore)

VaultAppRoleCertSSHStore = _reflection.GeneratedProtocolMessageType('VaultAppRoleCertSSHStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAPPROLECERTSSHSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAppRoleCertSSHStore)
  })
_sym_db.RegisterMessage(VaultAppRoleCertSSHStore)

VaultAppRoleCertX509Store = _reflection.GeneratedProtocolMessageType('VaultAppRoleCertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _VAULTAPPROLECERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultAppRoleCertX509Store)
  })
_sym_db.RegisterMessage(VaultAppRoleCertX509Store)

VaultTLSStore = _reflection.GeneratedProtocolMessageType('VaultTLSStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTTLSSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultTLSStore)
  })
_sym_db.RegisterMessage(VaultTLSStore)

VaultTLSCertSSHStore = _reflection.GeneratedProtocolMessageType('VaultTLSCertSSHStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTTLSCERTSSHSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultTLSCertSSHStore)
  })
_sym_db.RegisterMessage(VaultTLSCertSSHStore)

VaultTLSCertX509Store = _reflection.GeneratedProtocolMessageType('VaultTLSCertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _VAULTTLSCERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultTLSCertX509Store)
  })
_sym_db.RegisterMessage(VaultTLSCertX509Store)

VaultTokenStore = _reflection.GeneratedProtocolMessageType('VaultTokenStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTTOKENSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultTokenStore)
  })
_sym_db.RegisterMessage(VaultTokenStore)

VaultTokenCertSSHStore = _reflection.GeneratedProtocolMessageType('VaultTokenCertSSHStore', (_message.Message,), {
  'DESCRIPTOR' : _VAULTTOKENCERTSSHSTORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultTokenCertSSHStore)
  })
_sym_db.RegisterMessage(VaultTokenCertSSHStore)

VaultTokenCertX509Store = _reflection.GeneratedProtocolMessageType('VaultTokenCertX509Store', (_message.Message,), {
  'DESCRIPTOR' : _VAULTTOKENCERTX509STORE,
  '__module__' : 'secret_store_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.VaultTokenCertX509Store)
  })
_sym_db.RegisterMessage(VaultTokenCertX509Store)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\031SecretStoresTypesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _SECRETSTORE.oneofs_by_name['secret_store']._options = None
  _SECRETSTORE.oneofs_by_name['secret_store']._serialized_options = b'\252\370\263\007\t\252\370\263\007\004tags\252\370\263\007\t\252\370\263\007\004name'
  _SECRETSTORE.fields_by_name['aws']._options = None
  _SECRETSTORE.fields_by_name['aws']._serialized_options = b'\362\370\263\007\035\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003aws\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['aws_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['aws_cert_x_509']._serialized_options = b'\362\370\263\007%\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013awsCertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['active_directory']._options = None
  _SECRETSTORE.fields_by_name['active_directory']._serialized_options = b'\362\370\263\007)\312\363\263\007$\302\364\263\007\037\n\014json_gateway\022\017activeDirectory\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['azure']._options = None
  _SECRETSTORE.fields_by_name['azure']._serialized_options = b'\362\370\263\007\037\312\363\263\007\032\302\364\263\007\025\n\014json_gateway\022\005azure\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['cyberark_conjur']._options = None
  _SECRETSTORE.fields_by_name['cyberark_conjur']._serialized_options = b'\362\370\263\007(\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016cyberarkConjur\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['cyberark_pam']._options = None
  _SECRETSTORE.fields_by_name['cyberark_pam']._serialized_options = b'\362\370\263\007%\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013cyberarkPAM\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['cyberark_pam_experimental']._options = None
  _SECRETSTORE.fields_by_name['cyberark_pam_experimental']._serialized_options = b'\362\370\263\0071\312\363\263\007,\302\364\263\007\'\n\014json_gateway\022\027cyberarkPAMExperimental\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['delinea']._options = None
  _SECRETSTORE.fields_by_name['delinea']._serialized_options = b'\362\370\263\007!\312\363\263\007\034\302\364\263\007\027\n\014json_gateway\022\007delinea\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['gcp']._options = None
  _SECRETSTORE.fields_by_name['gcp']._serialized_options = b'\362\370\263\007\035\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003gcp\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['gcp_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['gcp_cert_x_509']._serialized_options = b'\362\370\263\007%\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013gcpCertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['keyfactor_ssh']._options = None
  _SECRETSTORE.fields_by_name['keyfactor_ssh']._serialized_options = b'\362\370\263\007&\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014keyfactorSSH\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['keyfactor_x_509']._options = None
  _SECRETSTORE.fields_by_name['keyfactor_x_509']._serialized_options = b'\362\370\263\007\'\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rkeyfactorX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['strong_vault']._options = None
  _SECRETSTORE.fields_by_name['strong_vault']._serialized_options = b'\362\370\263\007%\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013strongVault\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_awsec_2']._options = None
  _SECRETSTORE.fields_by_name['vault_awsec_2']._serialized_options = b'\362\370\263\007%\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013vaultAWSEC2\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_awsec_2_cert_ssh']._options = None
  _SECRETSTORE.fields_by_name['vault_awsec_2_cert_ssh']._serialized_options = b'\362\370\263\007,\312\363\263\007\'\302\364\263\007\"\n\014json_gateway\022\022vaultAWSEC2CertSSH\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_awsec_2_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['vault_awsec_2_cert_x_509']._serialized_options = b'\362\370\263\007-\312\363\263\007(\302\364\263\007#\n\014json_gateway\022\023vaultAWSEC2CertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_awsiam']._options = None
  _SECRETSTORE.fields_by_name['vault_awsiam']._serialized_options = b'\362\370\263\007%\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013vaultAWSIAM\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_awsiam_cert_ssh']._options = None
  _SECRETSTORE.fields_by_name['vault_awsiam_cert_ssh']._serialized_options = b'\362\370\263\007,\312\363\263\007\'\302\364\263\007\"\n\014json_gateway\022\022vaultAWSIAMCertSSH\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_awsiam_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['vault_awsiam_cert_x_509']._serialized_options = b'\362\370\263\007-\312\363\263\007(\302\364\263\007#\n\014json_gateway\022\023vaultAWSIAMCertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_app_role']._options = None
  _SECRETSTORE.fields_by_name['vault_app_role']._serialized_options = b'\362\370\263\007&\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014vaultAppRole\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_app_role_cert_ssh']._options = None
  _SECRETSTORE.fields_by_name['vault_app_role_cert_ssh']._serialized_options = b'\362\370\263\007-\312\363\263\007(\302\364\263\007#\n\014json_gateway\022\023vaultAppRoleCertSSH\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_app_role_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['vault_app_role_cert_x_509']._serialized_options = b'\362\370\263\007.\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024vaultAppRoleCertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_tls']._options = None
  _SECRETSTORE.fields_by_name['vault_tls']._serialized_options = b'\362\370\263\007\"\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010vaultTLS\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_tls_cert_ssh']._options = None
  _SECRETSTORE.fields_by_name['vault_tls_cert_ssh']._serialized_options = b'\362\370\263\007)\312\363\263\007$\302\364\263\007\037\n\014json_gateway\022\017vaultTLSCertSSH\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_tls_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['vault_tls_cert_x_509']._serialized_options = b'\362\370\263\007*\312\363\263\007%\302\364\263\007 \n\014json_gateway\022\020vaultTLSCertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_token']._options = None
  _SECRETSTORE.fields_by_name['vault_token']._serialized_options = b'\362\370\263\007$\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\nvaultToken\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_token_cert_ssh']._options = None
  _SECRETSTORE.fields_by_name['vault_token_cert_ssh']._serialized_options = b'\362\370\263\007+\312\363\263\007&\302\364\263\007!\n\014json_gateway\022\021vaultTokenCertSSH\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE.fields_by_name['vault_token_cert_x_509']._options = None
  _SECRETSTORE.fields_by_name['vault_token_cert_x_509']._serialized_options = b'\362\370\263\007,\312\363\263\007\'\302\364\263\007\"\n\014json_gateway\022\022vaultTokenCertX509\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORE._options = None
  _SECRETSTORE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _AWSSTORE.fields_by_name['id']._options = None
  _AWSSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSSTORE.fields_by_name['name']._options = None
  _AWSSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _AWSSTORE.fields_by_name['region']._options = None
  _AWSSTORE.fields_by_name['region']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006region'
  _AWSSTORE.fields_by_name['role_arn']._options = None
  _AWSSTORE.fields_by_name['role_arn']._serialized_options = b'\362\370\263\007&\260\363\263\007\001\312\363\263\007\034\302\364\263\007\027\n\014json_gateway\022\007roleArn'
  _AWSSTORE.fields_by_name['role_external_id']._options = None
  _AWSSTORE.fields_by_name['role_external_id']._serialized_options = b'\362\370\263\007-\260\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016roleExternalId'
  _AWSSTORE.fields_by_name['tags']._options = None
  _AWSSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSSTORE._options = None
  _AWSSTORE._serialized_options = b'\372\370\263\007O\250\363\263\007\001\312\363\263\007E\302\364\263\007\n\n\003cli\022\003aws\302\364\263\007\023\n\014json_gateway\022\003aws\302\364\263\007\031\n\022terraform-provider\022\003aws'
  _AWSCERTX509STORE.fields_by_name['id']._options = None
  _AWSCERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCERTX509STORE.fields_by_name['name']._options = None
  _AWSCERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _AWSCERTX509STORE.fields_by_name['caArn']._options = None
  _AWSCERTX509STORE.fields_by_name['caArn']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\300\363\263\007\001\312\363\263\007\032\302\364\263\007\025\n\014json_gateway\022\005caArn'
  _AWSCERTX509STORE.fields_by_name['certificateTemplateArn']._options = None
  _AWSCERTX509STORE.fields_by_name['certificateTemplateArn']._serialized_options = b'\362\370\263\007:\260\363\263\007\001\300\363\263\007\001\312\363\263\007+\302\364\263\007&\n\014json_gateway\022\026certificateTemplateArn'
  _AWSCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _AWSCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _AWSCERTX509STORE.fields_by_name['region']._options = None
  _AWSCERTX509STORE.fields_by_name['region']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006region'
  _AWSCERTX509STORE.fields_by_name['signingAlgo']._options = None
  _AWSCERTX509STORE.fields_by_name['signingAlgo']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingAlgo'
  _AWSCERTX509STORE.fields_by_name['tags']._options = None
  _AWSCERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCERTX509STORE._options = None
  _AWSCERTX509STORE._serialized_options = b'\372\370\263\007i\250\363\263\007\001\312\363\263\007_\302\364\263\007\022\n\003cli\022\013awsCertX509\302\364\263\007\033\n\014json_gateway\022\013awsCertX509\302\364\263\007#\n\022terraform-provider\022\raws_cert_x509'
  _ACTIVEDIRECTORYSTORE.fields_by_name['id']._options = None
  _ACTIVEDIRECTORYSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYSTORE.fields_by_name['name']._options = None
  _ACTIVEDIRECTORYSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYSTORE.fields_by_name['server_address']._options = None
  _ACTIVEDIRECTORYSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _ACTIVEDIRECTORYSTORE.fields_by_name['tags']._options = None
  _ACTIVEDIRECTORYSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYSTORE._options = None
  _ACTIVEDIRECTORYSTORE._serialized_options = b'\372\370\263\007I\250\363\263\007\001\312\363\263\007?\302\364\263\007\026\n\003cli\022\017activeDirectory\302\364\263\007\037\n\014json_gateway\022\017activeDirectory'
  _AZURESTORE.fields_by_name['id']._options = None
  _AZURESTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURESTORE.fields_by_name['name']._options = None
  _AZURESTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _AZURESTORE.fields_by_name['vault_uri']._options = None
  _AZURESTORE.fields_by_name['vault_uri']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010vaultUri'
  _AZURESTORE.fields_by_name['tags']._options = None
  _AZURESTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURESTORE._options = None
  _AZURESTORE._serialized_options = b'\372\370\263\0075\250\363\263\007\001\312\363\263\007+\302\364\263\007\014\n\003cli\022\005azure\302\364\263\007\025\n\014json_gateway\022\005azure'
  _CYBERARKCONJURSTORE.fields_by_name['id']._options = None
  _CYBERARKCONJURSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CYBERARKCONJURSTORE.fields_by_name['name']._options = None
  _CYBERARKCONJURSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _CYBERARKCONJURSTORE.fields_by_name['appURL']._options = None
  _CYBERARKCONJURSTORE.fields_by_name['appURL']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006appUrl'
  _CYBERARKCONJURSTORE.fields_by_name['tags']._options = None
  _CYBERARKCONJURSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CYBERARKCONJURSTORE._options = None
  _CYBERARKCONJURSTORE._serialized_options = b'\372\370\263\007q\250\363\263\007\001\312\363\263\007g\302\364\263\007\025\n\003cli\022\016cyberarkConjur\302\364\263\007\036\n\014json_gateway\022\016cyberarkConjur\302\364\263\007%\n\022terraform-provider\022\017cyberark_conjur'
  _CYBERARKPAMSTORE.fields_by_name['id']._options = None
  _CYBERARKPAMSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CYBERARKPAMSTORE.fields_by_name['name']._options = None
  _CYBERARKPAMSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _CYBERARKPAMSTORE.fields_by_name['appURL']._options = None
  _CYBERARKPAMSTORE.fields_by_name['appURL']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006appUrl'
  _CYBERARKPAMSTORE.fields_by_name['tags']._options = None
  _CYBERARKPAMSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CYBERARKPAMSTORE._options = None
  _CYBERARKPAMSTORE._serialized_options = b'\372\370\263\007h\250\363\263\007\001\312\363\263\007^\302\364\263\007\022\n\003cli\022\013cyberarkPAM\302\364\263\007\033\n\014json_gateway\022\013cyberarkPAM\302\364\263\007\"\n\022terraform-provider\022\014cyberark_pam'
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['id']._options = None
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['name']._options = None
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['appURL']._options = None
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['appURL']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006appUrl'
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['tags']._options = None
  _CYBERARKPAMEXPERIMENTALSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CYBERARKPAMEXPERIMENTALSTORE._options = None
  _CYBERARKPAMEXPERIMENTALSTORE._serialized_options = b'\372\370\263\007\223\001\250\363\263\007\001\312\363\263\007\210\001\210\364\263\007\001\302\364\263\007\036\n\003cli\022\027cyberarkPAMExperimental\302\364\263\007\'\n\014json_gateway\022\027cyberarkPAMExperimental\302\364\263\007/\n\022terraform-provider\022\031cyberark_pam_experimental'
  _DELINEASTORE.fields_by_name['id']._options = None
  _DELINEASTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _DELINEASTORE.fields_by_name['name']._options = None
  _DELINEASTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _DELINEASTORE.fields_by_name['server_url']._options = None
  _DELINEASTORE.fields_by_name['server_url']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tserverUrl'
  _DELINEASTORE.fields_by_name['tenant_name']._options = None
  _DELINEASTORE.fields_by_name['tenant_name']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\ntenantName'
  _DELINEASTORE.fields_by_name['tags']._options = None
  _DELINEASTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _DELINEASTORE._options = None
  _DELINEASTORE._serialized_options = b'\372\370\263\0079\250\363\263\007\001\312\363\263\007/\302\364\263\007\016\n\003cli\022\007delinea\302\364\263\007\027\n\014json_gateway\022\007delinea'
  _GCPSTORE.fields_by_name['id']._options = None
  _GCPSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPSTORE.fields_by_name['name']._options = None
  _GCPSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GCPSTORE.fields_by_name['projectID']._options = None
  _GCPSTORE.fields_by_name['projectID']._serialized_options = b'\362\370\263\007-\260\363\263\007\001\300\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tprojectId'
  _GCPSTORE.fields_by_name['tags']._options = None
  _GCPSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPSTORE._options = None
  _GCPSTORE._serialized_options = b'\372\370\263\0071\250\363\263\007\001\312\363\263\007\'\302\364\263\007\n\n\003cli\022\003gcp\302\364\263\007\023\n\014json_gateway\022\003gcp'
  _GCPCERTX509STORE.fields_by_name['id']._options = None
  _GCPCERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCERTX509STORE.fields_by_name['name']._options = None
  _GCPCERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GCPCERTX509STORE.fields_by_name['caID']._options = None
  _GCPCERTX509STORE.fields_by_name['caID']._serialized_options = b'\362\370\263\007#\260\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004caId'
  _GCPCERTX509STORE.fields_by_name['caPoolID']._options = None
  _GCPCERTX509STORE.fields_by_name['caPoolID']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010caPoolId'
  _GCPCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _GCPCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _GCPCERTX509STORE.fields_by_name['location']._options = None
  _GCPCERTX509STORE.fields_by_name['location']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010location'
  _GCPCERTX509STORE.fields_by_name['projectID']._options = None
  _GCPCERTX509STORE.fields_by_name['projectID']._serialized_options = b'\362\370\263\007-\260\363\263\007\001\300\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tprojectId'
  _GCPCERTX509STORE.fields_by_name['tags']._options = None
  _GCPCERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCERTX509STORE._options = None
  _GCPCERTX509STORE._serialized_options = b'\372\370\263\007A\250\363\263\007\001\312\363\263\0077\302\364\263\007\022\n\003cli\022\013gcpCertX509\302\364\263\007\033\n\014json_gateway\022\013gcpCertX509'
  _KEYFACTORSSHSTORE.fields_by_name['id']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYFACTORSSHSTORE.fields_by_name['name']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYFACTORSSHSTORE.fields_by_name['ca_file_path']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['ca_file_path']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\ncaFilePath'
  _KEYFACTORSSHSTORE.fields_by_name['certificate_file_path']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['certificate_file_path']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\300\363\263\007\001\312\363\263\007(\302\364\263\007#\n\014json_gateway\022\023certificateFilePath'
  _KEYFACTORSSHSTORE.fields_by_name['default_certificate_authority_name']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['default_certificate_authority_name']._serialized_options = b'\362\370\263\007C\260\363\263\007\001\300\363\263\007\001\312\363\263\0074\302\364\263\007/\n\014json_gateway\022\037defaultCertificateAuthorityName'
  _KEYFACTORSSHSTORE.fields_by_name['default_certificate_profile_name']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['default_certificate_profile_name']._serialized_options = b'\362\370\263\007A\260\363\263\007\001\300\363\263\007\001\312\363\263\0072\302\364\263\007-\n\014json_gateway\022\035defaultCertificateProfileName'
  _KEYFACTORSSHSTORE.fields_by_name['default_end_entity_profile_name']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['default_end_entity_profile_name']._serialized_options = b'\362\370\263\007?\260\363\263\007\001\300\363\263\007\001\312\363\263\0070\302\364\263\007+\n\014json_gateway\022\033defaultEndEntityProfileName'
  _KEYFACTORSSHSTORE.fields_by_name['enrollment_code_env_var']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['enrollment_code_env_var']._serialized_options = b'\362\370\263\0073\260\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024enrollmentCodeEnvVar'
  _KEYFACTORSSHSTORE.fields_by_name['enrollment_username_env_var']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['enrollment_username_env_var']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\014json_gateway\022\030enrollmentUsernameEnvVar'
  _KEYFACTORSSHSTORE.fields_by_name['key_file_path']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['key_file_path']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013keyFilePath'
  _KEYFACTORSSHSTORE.fields_by_name['server_address']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _KEYFACTORSSHSTORE.fields_by_name['tags']._options = None
  _KEYFACTORSSHSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYFACTORSSHSTORE._options = None
  _KEYFACTORSSHSTORE._serialized_options = b'\372\370\263\007C\250\363\263\007\001\312\363\263\0079\302\364\263\007\023\n\003cli\022\014keyfactorSSH\302\364\263\007\034\n\014json_gateway\022\014keyfactorSSH'
  _KEYFACTORX509STORE.fields_by_name['id']._options = None
  _KEYFACTORX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYFACTORX509STORE.fields_by_name['name']._options = None
  _KEYFACTORX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYFACTORX509STORE.fields_by_name['ca_file_path']._options = None
  _KEYFACTORX509STORE.fields_by_name['ca_file_path']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\ncaFilePath'
  _KEYFACTORX509STORE.fields_by_name['certificate_file_path']._options = None
  _KEYFACTORX509STORE.fields_by_name['certificate_file_path']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\300\363\263\007\001\312\363\263\007(\302\364\263\007#\n\014json_gateway\022\023certificateFilePath'
  _KEYFACTORX509STORE.fields_by_name['default_certificate_authority_name']._options = None
  _KEYFACTORX509STORE.fields_by_name['default_certificate_authority_name']._serialized_options = b'\362\370\263\007C\260\363\263\007\001\300\363\263\007\001\312\363\263\0074\302\364\263\007/\n\014json_gateway\022\037defaultCertificateAuthorityName'
  _KEYFACTORX509STORE.fields_by_name['default_certificate_profile_name']._options = None
  _KEYFACTORX509STORE.fields_by_name['default_certificate_profile_name']._serialized_options = b'\362\370\263\007A\260\363\263\007\001\300\363\263\007\001\312\363\263\0072\302\364\263\007-\n\014json_gateway\022\035defaultCertificateProfileName'
  _KEYFACTORX509STORE.fields_by_name['default_end_entity_profile_name']._options = None
  _KEYFACTORX509STORE.fields_by_name['default_end_entity_profile_name']._serialized_options = b'\362\370\263\007?\260\363\263\007\001\300\363\263\007\001\312\363\263\0070\302\364\263\007+\n\014json_gateway\022\033defaultEndEntityProfileName'
  _KEYFACTORX509STORE.fields_by_name['enrollment_code_env_var']._options = None
  _KEYFACTORX509STORE.fields_by_name['enrollment_code_env_var']._serialized_options = b'\362\370\263\0073\260\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024enrollmentCodeEnvVar'
  _KEYFACTORX509STORE.fields_by_name['enrollment_username_env_var']._options = None
  _KEYFACTORX509STORE.fields_by_name['enrollment_username_env_var']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\014json_gateway\022\030enrollmentUsernameEnvVar'
  _KEYFACTORX509STORE.fields_by_name['key_file_path']._options = None
  _KEYFACTORX509STORE.fields_by_name['key_file_path']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013keyFilePath'
  _KEYFACTORX509STORE.fields_by_name['server_address']._options = None
  _KEYFACTORX509STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _KEYFACTORX509STORE.fields_by_name['tags']._options = None
  _KEYFACTORX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYFACTORX509STORE._options = None
  _KEYFACTORX509STORE._serialized_options = b'\372\370\263\007E\250\363\263\007\001\312\363\263\007;\302\364\263\007\024\n\003cli\022\rkeyfactorX509\302\364\263\007\035\n\014json_gateway\022\rkeyfactorX509'
  _STRONGVAULTSTORE.fields_by_name['id']._options = None
  _STRONGVAULTSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _STRONGVAULTSTORE.fields_by_name['name']._options = None
  _STRONGVAULTSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _STRONGVAULTSTORE.fields_by_name['tags']._options = None
  _STRONGVAULTSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _STRONGVAULTSTORE._options = None
  _STRONGVAULTSTORE._serialized_options = b'\372\370\263\007h\250\363\263\007\001\312\363\263\007^\302\364\263\007\022\n\003cli\022\013strongVault\302\364\263\007\033\n\014json_gateway\022\013strongVault\302\364\263\007\"\n\022terraform-provider\022\014strong_vault'
  _VAULTAWSEC2STORE.fields_by_name['id']._options = None
  _VAULTAWSEC2STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSEC2STORE.fields_by_name['name']._options = None
  _VAULTAWSEC2STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAWSEC2STORE.fields_by_name['namespace']._options = None
  _VAULTAWSEC2STORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAWSEC2STORE.fields_by_name['server_address']._options = None
  _VAULTAWSEC2STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAWSEC2STORE.fields_by_name['tags']._options = None
  _VAULTAWSEC2STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSEC2STORE._options = None
  _VAULTAWSEC2STORE._serialized_options = b'\372\370\263\007i\250\363\263\007\001\312\363\263\007_\302\364\263\007\022\n\003cli\022\013vaultAWSEC2\302\364\263\007\033\n\014json_gateway\022\013vaultAWSEC2\302\364\263\007#\n\022terraform-provider\022\rvault_aws_ec2'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['id']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['name']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['namespace']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['server_address']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['signing_role']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['ssh_mount_point']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['ssh_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rsshMountPoint'
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['tags']._options = None
  _VAULTAWSEC2CERTSSHSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSEC2CERTSSHSTORE._options = None
  _VAULTAWSEC2CERTSSHSTORE._serialized_options = b'\372\370\263\007\200\001\250\363\263\007\001\312\363\263\007v\302\364\263\007\031\n\003cli\022\022vaultAWSEC2CertSSH\302\364\263\007\"\n\014json_gateway\022\022vaultAWSEC2CertSSH\302\364\263\007,\n\022terraform-provider\022\026vault_aws_ec2_cert_ssh'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['id']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['name']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['namespace']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['pki_mount_point']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['pki_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rpkiMountPoint'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['server_address']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['signing_role']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTAWSEC2CERTX509STORE.fields_by_name['tags']._options = None
  _VAULTAWSEC2CERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSEC2CERTX509STORE._options = None
  _VAULTAWSEC2CERTX509STORE._serialized_options = b'\372\370\263\007\203\001\250\363\263\007\001\312\363\263\007y\302\364\263\007\032\n\003cli\022\023vaultAWSEC2CertX509\302\364\263\007#\n\014json_gateway\022\023vaultAWSEC2CertX509\302\364\263\007-\n\022terraform-provider\022\027vault_aws_ec2_cert_x509'
  _VAULTAWSIAMSTORE.fields_by_name['id']._options = None
  _VAULTAWSIAMSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSIAMSTORE.fields_by_name['name']._options = None
  _VAULTAWSIAMSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAWSIAMSTORE.fields_by_name['namespace']._options = None
  _VAULTAWSIAMSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAWSIAMSTORE.fields_by_name['server_address']._options = None
  _VAULTAWSIAMSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAWSIAMSTORE.fields_by_name['tags']._options = None
  _VAULTAWSIAMSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSIAMSTORE._options = None
  _VAULTAWSIAMSTORE._serialized_options = b'\372\370\263\007i\250\363\263\007\001\312\363\263\007_\302\364\263\007\022\n\003cli\022\013vaultAWSIAM\302\364\263\007\033\n\014json_gateway\022\013vaultAWSIAM\302\364\263\007#\n\022terraform-provider\022\rvault_aws_iam'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['id']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['name']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['namespace']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['server_address']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['signing_role']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['ssh_mount_point']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['ssh_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rsshMountPoint'
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['tags']._options = None
  _VAULTAWSIAMCERTSSHSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSIAMCERTSSHSTORE._options = None
  _VAULTAWSIAMCERTSSHSTORE._serialized_options = b'\372\370\263\007\200\001\250\363\263\007\001\312\363\263\007v\302\364\263\007\031\n\003cli\022\022vaultAWSIAMCertSSH\302\364\263\007\"\n\014json_gateway\022\022vaultAWSIAMCertSSH\302\364\263\007,\n\022terraform-provider\022\026vault_aws_iam_cert_ssh'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['id']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['name']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['namespace']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['pki_mount_point']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['pki_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rpkiMountPoint'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['server_address']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['signing_role']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTAWSIAMCERTX509STORE.fields_by_name['tags']._options = None
  _VAULTAWSIAMCERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAWSIAMCERTX509STORE._options = None
  _VAULTAWSIAMCERTX509STORE._serialized_options = b'\372\370\263\007\203\001\250\363\263\007\001\312\363\263\007y\302\364\263\007\032\n\003cli\022\023vaultAWSIAMCertX509\302\364\263\007#\n\014json_gateway\022\023vaultAWSIAMCertX509\302\364\263\007-\n\022terraform-provider\022\027vault_aws_iam_cert_x509'
  _VAULTAPPROLESTORE.fields_by_name['id']._options = None
  _VAULTAPPROLESTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAPPROLESTORE.fields_by_name['name']._options = None
  _VAULTAPPROLESTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAPPROLESTORE.fields_by_name['namespace']._options = None
  _VAULTAPPROLESTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAPPROLESTORE.fields_by_name['server_address']._options = None
  _VAULTAPPROLESTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAPPROLESTORE.fields_by_name['tags']._options = None
  _VAULTAPPROLESTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAPPROLESTORE._options = None
  _VAULTAPPROLESTORE._serialized_options = b'\372\370\263\007k\250\363\263\007\001\312\363\263\007a\302\364\263\007\023\n\003cli\022\014vaultAppRole\302\364\263\007\034\n\014json_gateway\022\014vaultAppRole\302\364\263\007#\n\022terraform-provider\022\rvault_approle'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['id']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['name']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['namespace']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['server_address']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['signing_role']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['ssh_mount_point']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['ssh_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rsshMountPoint'
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['tags']._options = None
  _VAULTAPPROLECERTSSHSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAPPROLECERTSSHSTORE._options = None
  _VAULTAPPROLECERTSSHSTORE._serialized_options = b'\372\370\263\007\202\001\250\363\263\007\001\312\363\263\007x\302\364\263\007\032\n\003cli\022\023vaultAppRoleCertSSH\302\364\263\007#\n\014json_gateway\022\023vaultAppRoleCertSSH\302\364\263\007,\n\022terraform-provider\022\026vault_approle_cert_ssh'
  _VAULTAPPROLECERTX509STORE.fields_by_name['id']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAPPROLECERTX509STORE.fields_by_name['name']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTAPPROLECERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTAPPROLECERTX509STORE.fields_by_name['namespace']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTAPPROLECERTX509STORE.fields_by_name['pki_mount_point']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['pki_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rpkiMountPoint'
  _VAULTAPPROLECERTX509STORE.fields_by_name['server_address']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTAPPROLECERTX509STORE.fields_by_name['signing_role']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTAPPROLECERTX509STORE.fields_by_name['tags']._options = None
  _VAULTAPPROLECERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTAPPROLECERTX509STORE._options = None
  _VAULTAPPROLECERTX509STORE._serialized_options = b'\372\370\263\007\205\001\250\363\263\007\001\312\363\263\007{\302\364\263\007\033\n\003cli\022\024vaultAppRoleCertX509\302\364\263\007$\n\014json_gateway\022\024vaultAppRoleCertX509\302\364\263\007-\n\022terraform-provider\022\027vault_approle_cert_x509'
  _VAULTTLSSTORE.fields_by_name['id']._options = None
  _VAULTTLSSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTLSSTORE.fields_by_name['name']._options = None
  _VAULTTLSSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTTLSSTORE.fields_by_name['CA_cert_path']._options = None
  _VAULTTLSSTORE.fields_by_name['CA_cert_path']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\ncaCertPath'
  _VAULTTLSSTORE.fields_by_name['client_cert_path']._options = None
  _VAULTTLSSTORE.fields_by_name['client_cert_path']._serialized_options = b'\362\370\263\0072\260\363\263\007\001\300\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016clientCertPath'
  _VAULTTLSSTORE.fields_by_name['client_key_path']._options = None
  _VAULTTLSSTORE.fields_by_name['client_key_path']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rclientKeyPath'
  _VAULTTLSSTORE.fields_by_name['namespace']._options = None
  _VAULTTLSSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTTLSSTORE.fields_by_name['server_address']._options = None
  _VAULTTLSSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTTLSSTORE.fields_by_name['tags']._options = None
  _VAULTTLSSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTLSSTORE._options = None
  _VAULTTLSSTORE._serialized_options = b'\372\370\263\007_\250\363\263\007\001\312\363\263\007U\302\364\263\007\017\n\003cli\022\010vaultTLS\302\364\263\007\030\n\014json_gateway\022\010vaultTLS\302\364\263\007\037\n\022terraform-provider\022\tvault_tls'
  _VAULTTLSCERTSSHSTORE.fields_by_name['id']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTLSCERTSSHSTORE.fields_by_name['name']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTTLSCERTSSHSTORE.fields_by_name['CA_cert_path']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['CA_cert_path']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\ncaCertPath'
  _VAULTTLSCERTSSHSTORE.fields_by_name['client_cert_path']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['client_cert_path']._serialized_options = b'\362\370\263\0072\260\363\263\007\001\300\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016clientCertPath'
  _VAULTTLSCERTSSHSTORE.fields_by_name['client_key_path']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['client_key_path']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rclientKeyPath'
  _VAULTTLSCERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTTLSCERTSSHSTORE.fields_by_name['namespace']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTTLSCERTSSHSTORE.fields_by_name['server_address']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTTLSCERTSSHSTORE.fields_by_name['signing_role']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTTLSCERTSSHSTORE.fields_by_name['ssh_mount_point']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['ssh_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rsshMountPoint'
  _VAULTTLSCERTSSHSTORE.fields_by_name['tags']._options = None
  _VAULTTLSCERTSSHSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTLSCERTSSHSTORE._options = None
  _VAULTTLSCERTSSHSTORE._serialized_options = b'\372\370\263\007v\250\363\263\007\001\312\363\263\007l\302\364\263\007\026\n\003cli\022\017vaultTLSCertSSH\302\364\263\007\037\n\014json_gateway\022\017vaultTLSCertSSH\302\364\263\007(\n\022terraform-provider\022\022vault_tls_cert_ssh'
  _VAULTTLSCERTX509STORE.fields_by_name['id']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTLSCERTX509STORE.fields_by_name['name']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTTLSCERTX509STORE.fields_by_name['CA_cert_path']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['CA_cert_path']._serialized_options = b'\362\370\263\007)\260\363\263\007\001\312\363\263\007\037\302\364\263\007\032\n\014json_gateway\022\ncaCertPath'
  _VAULTTLSCERTX509STORE.fields_by_name['client_cert_path']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['client_cert_path']._serialized_options = b'\362\370\263\0072\260\363\263\007\001\300\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016clientCertPath'
  _VAULTTLSCERTX509STORE.fields_by_name['client_key_path']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['client_key_path']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rclientKeyPath'
  _VAULTTLSCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTTLSCERTX509STORE.fields_by_name['namespace']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTTLSCERTX509STORE.fields_by_name['pki_mount_point']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['pki_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rpkiMountPoint'
  _VAULTTLSCERTX509STORE.fields_by_name['server_address']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTTLSCERTX509STORE.fields_by_name['signing_role']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTTLSCERTX509STORE.fields_by_name['tags']._options = None
  _VAULTTLSCERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTLSCERTX509STORE._options = None
  _VAULTTLSCERTX509STORE._serialized_options = b'\372\370\263\007y\250\363\263\007\001\312\363\263\007o\302\364\263\007\027\n\003cli\022\020vaultTLSCertX509\302\364\263\007 \n\014json_gateway\022\020vaultTLSCertX509\302\364\263\007)\n\022terraform-provider\022\023vault_tls_cert_x509'
  _VAULTTOKENSTORE.fields_by_name['id']._options = None
  _VAULTTOKENSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTOKENSTORE.fields_by_name['name']._options = None
  _VAULTTOKENSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTTOKENSTORE.fields_by_name['namespace']._options = None
  _VAULTTOKENSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTTOKENSTORE.fields_by_name['server_address']._options = None
  _VAULTTOKENSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTTOKENSTORE.fields_by_name['tags']._options = None
  _VAULTTOKENSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTOKENSTORE._options = None
  _VAULTTOKENSTORE._serialized_options = b'\372\370\263\007e\250\363\263\007\001\312\363\263\007[\302\364\263\007\021\n\003cli\022\nvaultToken\302\364\263\007\032\n\014json_gateway\022\nvaultToken\302\364\263\007!\n\022terraform-provider\022\013vault_token'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['id']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['name']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['namespace']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['server_address']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['signing_role']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['ssh_mount_point']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['ssh_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rsshMountPoint'
  _VAULTTOKENCERTSSHSTORE.fields_by_name['tags']._options = None
  _VAULTTOKENCERTSSHSTORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTOKENCERTSSHSTORE._options = None
  _VAULTTOKENCERTSSHSTORE._serialized_options = b'\372\370\263\007|\250\363\263\007\001\312\363\263\007r\302\364\263\007\030\n\003cli\022\021vaultTokenCertSSH\302\364\263\007!\n\014json_gateway\022\021vaultTokenCertSSH\302\364\263\007*\n\022terraform-provider\022\024vault_token_cert_ssh'
  _VAULTTOKENCERTX509STORE.fields_by_name['id']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTOKENCERTX509STORE.fields_by_name['name']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _VAULTTOKENCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['issuedCertTTLMinutes']._serialized_options = b'\362\370\263\0078\260\363\263\007\001\300\363\263\007\001\312\363\263\007)\302\364\263\007$\n\014json_gateway\022\024issuedCertTtlMinutes'
  _VAULTTOKENCERTX509STORE.fields_by_name['namespace']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['namespace']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tnamespace'
  _VAULTTOKENCERTX509STORE.fields_by_name['pki_mount_point']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['pki_mount_point']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rpkiMountPoint'
  _VAULTTOKENCERTX509STORE.fields_by_name['server_address']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['server_address']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\300\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rserverAddress'
  _VAULTTOKENCERTX509STORE.fields_by_name['signing_role']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['signing_role']._serialized_options = b'\362\370\263\007/\260\363\263\007\001\300\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013signingRole'
  _VAULTTOKENCERTX509STORE.fields_by_name['tags']._options = None
  _VAULTTOKENCERTX509STORE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _VAULTTOKENCERTX509STORE._options = None
  _VAULTTOKENCERTX509STORE._serialized_options = b'\372\370\263\007\177\250\363\263\007\001\312\363\263\007u\302\364\263\007\031\n\003cli\022\022vaultTokenCertX509\302\364\263\007\"\n\014json_gateway\022\022vaultTokenCertX509\302\364\263\007+\n\022terraform-provider\022\025vault_token_cert_x509'
  _SECRETSTORE._serialized_start=60
  _SECRETSTORE._serialized_end=3162
  _AWSSTORE._serialized_start=3165
  _AWSSTORE._serialized_end=3558
  _AWSCERTX509STORE._serialized_start=3561
  _AWSCERTX509STORE._serialized_end=4175
  _ACTIVEDIRECTORYSTORE._serialized_start=4178
  _ACTIVEDIRECTORYSTORE._serialized_end=4453
  _AZURESTORE._serialized_start=4456
  _AZURESTORE._serialized_end=4691
  _CYBERARKCONJURSTORE._serialized_start=4694
  _CYBERARKCONJURSTORE._serialized_end=4993
  _CYBERARKPAMSTORE._serialized_start=4996
  _CYBERARKPAMSTORE._serialized_end=5283
  _CYBERARKPAMEXPERIMENTALSTORE._serialized_start=5286
  _CYBERARKPAMEXPERIMENTALSTORE._serialized_end=5630
  _DELINEASTORE._serialized_start=5633
  _DELINEASTORE._serialized_end=5940
  _GCPSTORE._serialized_start=5943
  _GCPSTORE._serialized_end=6173
  _GCPCERTX509STORE._serialized_start=6176
  _GCPCERTX509STORE._serialized_end=6717
  _KEYFACTORSSHSTORE._serialized_start=6720
  _KEYFACTORSSHSTORE._serialized_end=7754
  _KEYFACTORX509STORE._serialized_start=7757
  _KEYFACTORX509STORE._serialized_end=8794
  _STRONGVAULTSTORE._serialized_start=8797
  _STRONGVAULTSTORE._serialized_end=9017
  _VAULTAWSEC2STORE._serialized_start=9020
  _VAULTAWSEC2STORE._serialized_end=9387
  _VAULTAWSEC2CERTSSHSTORE._serialized_start=9390
  _VAULTAWSEC2CERTSSHSTORE._serialized_end=10039
  _VAULTAWSEC2CERTX509STORE._serialized_start=10042
  _VAULTAWSEC2CERTX509STORE._serialized_end=10695
  _VAULTAWSIAMSTORE._serialized_start=10698
  _VAULTAWSIAMSTORE._serialized_end=11065
  _VAULTAWSIAMCERTSSHSTORE._serialized_start=11068
  _VAULTAWSIAMCERTSSHSTORE._serialized_end=11717
  _VAULTAWSIAMCERTX509STORE._serialized_start=11720
  _VAULTAWSIAMCERTX509STORE._serialized_end=12373
  _VAULTAPPROLESTORE._serialized_start=12376
  _VAULTAPPROLESTORE._serialized_end=12746
  _VAULTAPPROLECERTSSHSTORE._serialized_start=12749
  _VAULTAPPROLECERTSSHSTORE._serialized_end=13401
  _VAULTAPPROLECERTX509STORE._serialized_start=13404
  _VAULTAPPROLECERTX509STORE._serialized_end=14060
  _VAULTTLSSTORE._serialized_start=14063
  _VAULTTLSSTORE._serialized_end=14651
  _VAULTTLSCERTSSHSTORE._serialized_start=14654
  _VAULTTLSCERTSSHSTORE._serialized_end=15522
  _VAULTTLSCERTX509STORE._serialized_start=15525
  _VAULTTLSCERTX509STORE._serialized_end=16397
  _VAULTTOKENSTORE._serialized_start=16400
  _VAULTTOKENSTORE._serialized_end=16762
  _VAULTTOKENCERTSSHSTORE._serialized_start=16765
  _VAULTTOKENCERTSSHSTORE._serialized_end=17408
  _VAULTTOKENCERTX509STORE._serialized_start=17411
  _VAULTTOKENCERTX509STORE._serialized_end=18058
# @@protoc_insertion_point(module_scope)
